@@ -1,4 +1,4 @@
-from cmdcheatsheet.commands.core import delete_command
+from .core import delete_command
 from cmdcheatsheet.shared.models import CommandArgument, CommandDetails
 
 
