@@ -1,8 +1,10 @@
 __all__ = [
     'actions',
+    'alt_store_display_strategy',
     'consts',
     'core',
     'display',
+    'default_display_strategy',
     'display_available_configs',
     'display_config',
     'models',
